import { Form, Input, InputRef } from "antd";
import React, { useEffect, useRef, useState } from "react"

interface Props {
    title: string,
    dataIndex: string
    record: any;
    handleSave: (data: any) => void
}

const InputUpdate: React.FC<Props> = ({ title, dataIndex, record, handleSave }) => {
    const [form] = Form.useForm();
    const [editing, setEditing] = useState(false);
    const inputRef = useRef<InputRef>(null);

    useEffect(() => {
        if (editing) {
            inputRef.current!.focus({ cursor: 'all' });
        }
    }, [editing]);

    const toggleEdit = () => {
        setEditing(!editing);
        form.setFieldsValue({ [dataIndex]: record[dataIndex] });
    };

    const save = async () => {
        try {
            const values = await form.validateFields();
            if (values?.adgroupName !== (record as any)?.adgroupName) {
                handleSave({ ...record, ...values });
            }
            toggleEdit();
        } catch (errInfo) {
            console.log('Save failed:', errInfo);
        }
    };

    let childNode = editing ? (<Form form={form}><Form.Item
        style={{ margin: 0 }}
        name={dataIndex}
        rules={[{ required: true, message: `${title} is required.` }]}
    >
        <Input ref={inputRef} size="small" onPressEnter={save} onBlur={save} bordered />
    </Form.Item></Form>) : (<span className="editable-cell-value-wrap ellipsisText" onClick={toggleEdit}>
        {title}
    </span>)

    return childNode;
}


export default React.memo(InputUpdate)